[Orca-users] Re: Orca not pick up new logs (was Re: plot ambien t and cpu temperature on E450)

Blair Zajac blair at akamai.com
Wed Feb 28 09:15:19 PST 2001


If you run Orca using -o it'll take a lot of time to find all
of the input files, so if you can, it's better just to let Orca
run continuously.

There are two real solutions to the "too many open files" problem
in order of preference:

1) Before running Orca use either the limit or ulimit command to
   increase the number of allowed open file descriptors to 256:

   (csh or tcsh)
   limit descriptors 256
   orca ......

   or

   (sh or bash)
   ulimit -n 256
   orca ......
  
2) Apply the following patch to lib/Orca/OpenFileHash.pm (for Orca
   0.26):

--- OpenFileHash.pm.orig        Thu Mar  9 12:27:11 2000
+++ OpenFileHash.pm     Wed Feb 28 08:45:44 2001
@@ -14,12 +14,12 @@
 @ISA     = qw(Exporter);
 $VERSION = substr q$Revision: 0.01 $, 10;
 
 # Set up a cache of 100 open file descriptors for the source data
 # files.  This leaves a large number of free file descriptors for
 # other use in the program.
 use vars qw($open_file_cache);
 unless ($open_file_cache) {
-  $open_file_cache = Orca::OpenFileHash->new(100)
+  $open_file_cache = Orca::OpenFileHash->new(50)
 }
 
 # Export a global open file cache object.
@@ -14,12 +14,12 @@
 $VERSION = substr q$Revision: 0.01 $, 10;
 
-# Set up a cache of 100 open file descriptors for the source data
+# Set up a cache of 50 open file descriptors for the source data
 # files.  This leaves a large number of free file descriptors for
 # other use in the program.


Regards,
Blair

Adam Levin wrote:
> 
> On Wed, 28 Feb 2001, Blair Zajac wrote:
> > I think you only need to white space separate the column names:
> >       data ambient *9/5+32
> > so that Orca can distinguish the column name from the rest of
> > the statement.
> 
> Ok, that's good to know.  Whitespacing the whole thing works, so I'm
> happy
> to leave it that way.  If it ain't broke, and all that.
> 
> By the way, we have a machine basically dedicated to logging and
> generating the orca graphs.  Is there any reason why I might want to
> run
> orca -o instead of just launching orca and letting it run (I've been
> letting it run, and it's been fine).  If I launch it with -o, I get
> "too
> many open files" errors, so I'd have to start moving old percol-*
> files
> out from under orca's area, but then it should run, I think.
> 
> -Adam
> 
> Adam Levin, Senior Unix Systems Administrator |
> http://www.audible.com/
> Audible, Inc.
> Wayne, NJ, 07470        Bigjobs!
> 973-837-2797



More information about the Orca-users mailing list